# Dazvol

Authorization library for Python.

![PyPI](https://img.shields.io/pypi/v/dazvol)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/alex-oleshkevich/dazvol/Lint)
![GitHub](https://img.shields.io/github/license/alex-oleshkevich/dazvol)
![Libraries.io dependency status for latest release](https://img.shields.io/librariesio/release/pypi/dazvol)
![PyPI - Downloads](https://img.shields.io/pypi/dm/dazvol)
![GitHub Release Date](https://img.shields.io/github/release-date/alex-oleshkevich/dazvol)
![Lines of code](https://img.shields.io/tokei/lines/github/alex-oleshkevich/dazvol)

## Installation

Install `dazvol` using PIP or poetry:

```bash
pip install dazvol
# or
poetry add dazvol
```

## Features

-   TODO

## Quick start

See example application in `examples/` directory of this repository.
